@@ -7,8 +7,6 @@ use warnings;
 use base 'Class::Accessor::Fast';
 __PACKAGE__->mk_accessors( qw/storage prefix expires/ );
 
-our ($VERSION) = '$Revision: 2609 $' =~ m{ \$Revision: \s+ (\S+) }mx;
-
 =head2 get_info
 
 =cut
@@ -27,7 +25,7 @@ sub get_info {
     my $last_timeout;
     my $timeout;
     while ( defined ( $timeout = $self->get_item($number) ) ){
-        if ( ! $attempts || $size < $attempts ) {
+        if ( ! $attempts || ( $size < $attempts ) ) {
             $last_timeout = $timeout;
         }
         $size++;
@@ -35,7 +33,7 @@ sub get_info {
     }
     return { 
         size => $size, 
-        timeout => $last_timeout - time 
+        timeout => $last_timeout ? ( $last_timeout - time ) : ()
     };
 }
 
