@@ -18,11 +18,11 @@ sub test_backend {
     );
     my $oldsize = $c->get_info->{size};
     $c->increment;
-    is( $c->get_info->{size}, $oldsize + 1, 'append/size' );
+    is( $c->get_info(100)->{size}, $oldsize + 1, 'append/size' );
     $c->increment;
-    my $info = $c->get_info;
+    my $info = $c->get_info(100);
     is( $info->{size}, $oldsize + 2, 'yet another' );
-    cmp_ok( $info->{timeout}, '>=', time, 'timeout' );
+    cmp_ok( $info->{timeout}, '>=', 0, 'timeout' );
     sleep 3;
     $c->increment;
     sleep 3;
